Namespace for calculating beer colors
Namespace for calculating beer colors
Convert the color described in 'ebc` to the equivalent degrees Lovibond
Convert the color described in 'ebc` to the equivalent degrees Lovibond
Given ebc-number, return the closest, bounded applicable RGBA color string.
Given `ebc-number`, return the closest, bounded applicable RGBA color string.
(ebc->srm ebc)Convert the color described by the ebc to the equivalent SRM color
Convert the color described by the `ebc` to the equivalent SRM color
Convert the color described in degrees 'lovibond` to the equivalent EBC color
Convert the color described in degrees 'lovibond` to the equivalent EBC color
Given lovibond-number, return the closest, bounded applicable RGBA color string.
Given `lovibond-number`, return the closest, bounded applicable RGBA color string.
(lovibond->srm lovibond)Convert the color described in degrees lovibond to the equivalent SRM color
Convert the color described in degrees `lovibond` to the equivalent SRM color
(srm->ebc srm)Convert the color described by the srm to the equivalent EBC color
Convert the color described by the `srm` to the equivalent EBC color
(srm->lovibond srm)Convert the color described in 'srm` to the equivalent degrees Lovibond
Convert the color described in 'srm` to the equivalent degrees Lovibond
(srm->rgba srm-number)Given srm-number, return the closest, bounded applicable RGBA color string.
OPINIONATED: The provided srm-number will be bound to the common range from 1 to 40
Decimal-like values are trimmed, not rounded.
Given `srm-number`, return the closest, bounded applicable RGBA color string.
OPINIONATED: The provided `srm-number` will be bound to the common range from 1 to 40
Decimal-like values are trimmed, not rounded.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |