Namespace for handling numeric precision
Namespace for handling numeric precision
(->1dp x)Given a decimal x, returns that number rounded to one decimal place.
Given a decimal `x`, returns that number rounded to one decimal place.
(->2dp x)Given a decimal x, returns that number rounded to two decimal places.
Given a decimal `x`, returns that number rounded to two decimal places.
(->3dp x)Given a decimal x, returns that number rounded to three decimal places.
Given a decimal `x`, returns that number rounded to three decimal places.
(->precision x num-decimals)Given a decimal x and the number of decimal places, returns that number rounded to num-decimals precision
Given a decimal `x` and the number of decimal places, returns that number rounded to `num-decimals` precision
(approximates? n1 n2 variance)Determine if n2 approximates n1 within variance percent
Determine if `n2` approximates `n1` within `variance` percent
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |